@@ -13,7 +13,9 @@ class Http:
             "Authorization": f"Token {SEVERINO_API_TOKEN}",
         }
 
-    def __http_request(self, method: str, url: str, headers: dict = None, data=None):
+    def __http_request(
+        self, method: str, url: str, headers: dict = None, data=None, params=None
+    ):
         if headers is None:
             headers = {}
 
@@ -26,13 +28,18 @@ class Http:
             url=url,
             headers=headers,
             data=json.dumps(data),
+            params=params,
         )
 
     def post(self, url: str, headers: dict = None, data: dict = None):
         return self.__http_request(method="POST", url=url, headers=headers, data=data)
 
-    def get(self, url: str, headers: dict = None, data: dict = None):
-        return self.__http_request(method="GET", url=url, headers=headers, data=data)
+    def get(
+        self, url: str, headers: dict = None, data: dict = None, params: dict = None
+    ):
+        return self.__http_request(
+            method="GET", url=url, headers=headers, data=data, params=params
+        )
 
     def put(self, url: str, headers: dict = None, data: dict = None):
         return self.__http_request(method="PUT", url=url, headers=headers, data=data)
